@@ -119,6 +119,8 @@ except ImportError as error_text:
                 ignore_errors=True,
             )
 
+    restart_script = f'{sys.executable} {" ".join(sys.argv)}'
+    print(f'restarting script with command:\n{restart_script}')
     os.system(
-        sys.executable + " ".join(sys.path)
+        restart_script
     )
